@@ -329,12 +329,16 @@ class SSHClient(object):
 
                     # 强制创建当前文件的父目录（即使是子目录中的文件）
                     remote_file_parent = remote_file.parent
-                    self.exec(f"mkdir -p {remote_file_parent}")
-
+                    rs=self.exec(f"ls {remote_file_parent}")
+                    if rs.exit_status_code != 0:
+                        log.info(f" {self.__ip}:{self.__port} | 创建目录: {remote_file_parent}")
+                        self.exec(f"mkdir -p {remote_file_parent}")
+                    else:
+                        log.info(f" {self.__ip}:{self.__port} | 目录已存在: {remote_file_parent}")
                     # 上传文件
                     try:
                         self.__sftp.put(str(local_file), str(remote_file))
-                        log.debug(f" {self.__ip}:{self.__port} | 已拷贝: {local_file} -> {remote_file}")
+                        log.info(f" {self.__ip}:{self.__port} | 已拷贝: {local_file} -> {remote_file}")
                     except Exception as e:
                         log.error(
                             f" {self.__ip}:{self.__port} | 拷贝失败: {local_file} -> {remote_file}, 错误: {str(e)}")
